]> git.ipfire.org Git - people/pmueller/ipfire-2.x.git/commitdiff
Merge branch 'master' of git://git.ipfire.org/ipfire-2.x
authorMichael Tremer <michael.tremer@ipfire.org>
Wed, 26 Nov 2008 22:51:01 +0000 (23:51 +0100)
committerMichael Tremer <michael.tremer@ipfire.org>
Wed, 26 Nov 2008 22:51:01 +0000 (23:51 +0100)
config/rootfiles/packages/streamripper [new file with mode: 0644]
doc/packages-list.txt
html/cgi-bin/time.cgi
html/cgi-bin/vpnmain.cgi
lfs/streamripper [new file with mode: 0644]
make.sh
src/initscripts/init.d/tmpfs
src/scripts/settime
src/scripts/timecheck

diff --git a/config/rootfiles/packages/streamripper b/config/rootfiles/packages/streamripper
new file mode 100644 (file)
index 0000000..f3abba5
--- /dev/null
@@ -0,0 +1,14 @@
+usr/bin/agrep
+usr/bin/streamripper
+#usr/include/tre
+#usr/include/tre/regex.h
+#usr/include/tre/tre-config.h
+#usr/lib/libtre.a
+#usr/lib/libtre.la
+usr/lib/libtre.so
+usr/lib/libtre.so.4
+usr/lib/libtre.so.4.2.2
+#usr/lib/pkgconfig/tre.pc
+#usr/share/locale/fi/LC_MESSAGES/tre.mo
+#usr/share/man/man1/agrep.1
+#usr/share/man/man1/streamripper.1
index f0640b24c059c8cb9920a1309a0c390cf33a0284..f9ca8acc0d455e9e723191c313d09bad728da053 100644 (file)
@@ -62,7 +62,6 @@
 * ccache-2.4
 * cdrtools-2.01
 * centerim-4.22.1
-* clamav-0.94
 * clamav-0.94.1
 * cmake-2.4.8
 * collectd-4.5.1
 * lynis-1.2.1
 * lzo-2.02
 * m4-1.4.4
-* mISDNuser-1_1_8
 * mISDNuser.git-8e7bf2f11cc108d4b52949c2a26e38df24821b01
 * madwifi-hal-2008-08-15-r3862-20080903-kmod-2.6.25.19
 * make-3.81
 * squid-2.7.STABLE5
 * squidGuard-1.3
 * squidclamav-3.7
+* streamripper-1.63.5
 * sudo-1.6.8p12
 * sysfsutils-1.3.0
 * sysklogd-1.4.1
index 29bfd2f26ceab09d7cf0ef71d18239edc7caffbc..988a1484cc10fdb6a77180b120d55bf4c9cda6e1 100644 (file)
@@ -127,10 +127,10 @@ ERROR:
                system ('/usr/bin/touch', "${General::swroot}/time/enable");
                system ('/usr/local/bin/timectrl enable >/dev/null 2>&1');
                &General::log($Lang::tr{'ntp syncro enabled'});
-               unlink "${General::swroot}/time/counter";
+               unlink "/var/lock/time/counter";
                if ($timesettings{'UPDATE_METHOD'} eq 'periodically')
                {
-                       open(FILE, ">/${General::swroot}/time/counter") or die "Unable to write counter file";
+                       open(FILE, ">/var/lock/time/counter") or die "Unable to write counter file";
                        flock(FILE, 2);
                        print FILE "$updateperiod\n";
                        close FILE;
@@ -147,7 +147,7 @@ ERROR:
        else
        {
                unlink "${General::swroot}/time/enable";
-               unlink "${General::swroot}/time/settimenow";
+               unlink "/var/lock/time/settimenow";
                unlink "${General::swroot}/time/allowclients"; # DPC added to 1.3.1
                system ('/usr/local/bin/timectrl disable >/dev/null 2>&1');
                &General::log($Lang::tr{'ntp syncro disabled'})
@@ -162,7 +162,7 @@ ERROR:
 $timesettings{'ACTION'} = &Header::cleanhtml ($timesettings{'ACTION'});
 if ($timesettings{'ACTION'} eq $Lang::tr{'set time now'} && $timesettings{'ENABLENTP'} eq 'on')
 {
-       system ('/usr/bin/touch', "${General::swroot}/time/settimenow");
+       system ('/usr/bin/touch', "/var/lock/time/settimenow");
 }
 
 &General::readhash("${General::swroot}/time/settings", \%timesettings);
@@ -210,7 +210,7 @@ $selected{'UPDATE_PERIOD'}{$timesettings{'UPDATE_PERIOD'}} = "selected='selected
 
 # added to v0.0.4 to refresh screen if syncro event queued 
 my $refresh = '';
-if ( -e "${General::swroot}/time/settimenow") {
+if ( -e "/var/lock/time/settimenow") {
        $refresh = "<meta http-equiv='refresh' content='60;' />";
 }
 
@@ -240,10 +240,12 @@ print <<END
 END
 ;
 
-if ( -e "${General::swroot}/time/lastset")
+if ( -e "/var/lock/time/lastset")
 {
        print "$Lang::tr{'clock last synchronized at'}\n";
-       my $output = `cat ${General::swroot}/time/lastset`;
+       open(FILE, "</var/lock/time/lastset") or die "Unable to read lastset";
+       my $output = <FILE>;
+       close FILE;
        print $output;
 }
 else
@@ -292,7 +294,7 @@ print <<END
 END
 ;
 
-if ( -e "${General::swroot}/time/settimenow") {
+if ( -e "/var/lock/time/settimenow") {
        print "<tr>\n<td align='center'><img src='/images/clock.gif' alt='' /></td>\n";
        print "<td colspan='2'><font color='red'>$Lang::tr{'waiting to synchronize clock'}...</font></td></tr>\n";
 }
index 466eb0c8951fb0b343a5ce8fc8d8035a1d194eaf..c9c73274e7a395a620bb75e4e7e71d118dadc165 100644 (file)
@@ -2362,13 +2362,7 @@ if(($cgiparams{'ACTION'} eq $Lang::tr{'advanced'}) ||
 
            <td class='boldbase' align='right' valign='top'>$Lang::tr{'esp grouptype'}</td><td class='boldbase' valign='top'>
                <select name='ESP_GROUPTYPE'>
-               <option value=''>$Lang::tr{'phase1 group'}</option>
-               <option value='modp4096' $checked{'ESP_GROUPTYPE'}{'modp4096'}>MODP-4096</option>
-               <option value='modp3072' $checked{'ESP_GROUPTYPE'}{'modp3072'}>MODP-3072</option>
-               <option value='modp2048' $checked{'ESP_GROUPTYPE'}{'modp2048'}>MODP-2048</option>
-               <option value='modp1536' $checked{'ESP_GROUPTYPE'}{'modp1536'}>MODP-1536</option>
-               <option value='modp1024' $checked{'ESP_GROUPTYPE'}{'modp1024'}>MODP-1024</option>
-               <option value='modp768'  $checked{'ESP_GROUPTYPE'}{'modp768'}>MODP-768</option></select></td>
+               <option value=''>$Lang::tr{'phase1 group'}</option></select></td>
        </tr><tr>
            <td class='boldbase' align='right' valign='top'>$Lang::tr{'esp keylife'}</td><td class='boldbase' valign='top'>
                <input type='text' name='ESP_KEYLIFE' value='$cgiparams{'ESP_KEYLIFE'}' size='5' /> $Lang::tr{'hours'}</td>
diff --git a/lfs/streamripper b/lfs/streamripper
new file mode 100644 (file)
index 0000000..55efd40
--- /dev/null
@@ -0,0 +1,84 @@
+###############################################################################
+#                                                                             #
+# IPFire.org - A linux based firewall                                         #
+# Copyright (C) 2007  Michael Tremer & Christian Schmidt                      #
+#                                                                             #
+# This program is free software: you can redistribute it and/or modify        #
+# it under the terms of the GNU General Public License as published by        #
+# the Free Software Foundation, either version 3 of the License, or           #
+# (at your option) any later version.                                         #
+#                                                                             #
+# This program is distributed in the hope that it will be useful,             #
+# but WITHOUT ANY WARRANTY; without even the implied warranty of              #
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
+# GNU General Public License for more details.                                #
+#                                                                             #
+# You should have received a copy of the GNU General Public License           #
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.       #
+#                                                                             #
+###############################################################################
+
+###############################################################################
+# Definitions
+###############################################################################
+
+include Config
+
+VER        = 1.63.5
+
+THISAPP    = streamripper-$(VER)
+DL_FILE    = $(THISAPP).tar.gz
+DL_FROM    = $(URL_IPFIRE)
+DIR_APP    = $(DIR_SRC)/$(THISAPP)
+TARGET     = $(DIR_INFO)/$(THISAPP)
+PROG       = streamripper
+PAK_VER    = 1
+
+DEPS       = "libmad libogg libvorbis"
+
+###############################################################################
+# Top-level Rules
+###############################################################################
+
+objects = $(DL_FILE)
+
+$(DL_FILE) = $(DL_FROM)/$(DL_FILE)
+
+$(DL_FILE)_MD5 = 73a63383dca00615c3328cf51bf2fa56
+
+install : $(TARGET)
+
+check : $(patsubst %,$(DIR_CHK)/%,$(objects))
+
+download :$(patsubst %,$(DIR_DL)/%,$(objects))
+
+md5 : $(subst %,%_MD5,$(objects))
+
+###############################################################################
+# Downloading, checking, md5sum
+###############################################################################
+
+$(patsubst %,$(DIR_CHK)/%,$(objects)) :
+       @$(CHECK)
+
+$(patsubst %,$(DIR_DL)/%,$(objects)) :
+       @$(LOAD)
+
+$(subst %,%_MD5,$(objects)) :
+       @$(MD5)
+
+dist: 
+       @$(PAK)
+
+###############################################################################
+# Installation Details
+###############################################################################
+
+$(TARGET) : $(patsubst %,$(DIR_DL)/%,$(objects))
+       @$(PREBUILD)
+       @rm -rf $(DIR_APP) && cd $(DIR_SRC) && tar zxf $(DIR_DL)/$(DL_FILE)
+       cd $(DIR_APP) && ./configure prefix=/usr
+       cd $(DIR_APP) && make $(MAKETUNING)
+       cd $(DIR_APP) && make install
+       @rm -rf $(DIR_APP)
+       @$(POSTBUILD)
diff --git a/make.sh b/make.sh
index f1e40623fdc74194d4290ee179fb24413d7cc47b..2c5a1115042b7e600d829315eac4f5ec3ca680b0 100755 (executable)
--- a/make.sh
+++ b/make.sh
@@ -583,6 +583,7 @@ buildipfire() {
   ipfiremake lynis
   ipfiremake cryptsetup
   ipfiremake splix
+  ipfiremake streamripper
   echo Build on $HOSTNAME > $BASEDIR/build/var/ipfire/firebuild
   cat /proc/version >> $BASEDIR/build/var/ipfire/firebuild
   echo >> $BASEDIR/build/var/ipfire/firebuild
index fc45db231487e9dc0c7605dd7dbebc81d23ce8f9..41d6a1df96e7af51eab316c53f03963e9b23ad05 100644 (file)
@@ -25,6 +25,10 @@ case "$1" in
                if [ ! -e /var/lock/subsys ]; then
                        mkdir -p /var/lock/subsys
                fi
+               if [ ! -e /var/lock/time ]; then
+                       mkdir -p /var/lock/time
+                       chown nobody.root /var/lock/time
+               fi
                if [ ! -e /var/run/clamav ]; then
                        mkdir -p /var/run/clamav
                        chown clamav:clamav /var/run/clamav
index cede5f8c11009e9e85fc741d738731d05b00357d..0bfcf3edf606b4f3397dd5dc434cc19daee90868 100644 (file)
@@ -44,18 +44,18 @@ if [ -n "$1" ]; then
 
                if [ "$ntpdatetest" -eq 0 ]; then
                        case $tlanguage in
-                               en ) date "+%X %Z on %d %B %Y" > /var/ipfire/time/lastset ;
+                               en ) date "+%X %Z on %d %B %Y" > /var/lock/time/lastset ;
                                        logger -t ipfire "NTP synchronisation event" ;;
-                               de ) date "+%X Uhr am %d.%m.%Y" > /var/ipfire/time/lastset ;
+                               de ) date "+%X Uhr am %d.%m.%Y" > /var/lock/time/lastset ;
                                        logger -t ipfire "NTP Synchronisierung" ;;
-                               *  ) date "+%X %Z, %Y-%m-%d" > /var/ipfire/time/lastset ;
+                               *  ) date "+%X %Z, %Y-%m-%d" > /var/lock/time/lastset ;
                                        logger -t ipfire "NTP synchronisation" ;;
                        esac
 
                        /sbin/hwclock --systohc
-                       rm -f /var/ipfire/time/settimenow
+                       rm -f /var/lock/time/settimenow
                        # reset counter variable
-                       cp /var/ipfire/time/counter.conf /var/ipfire/time/counter
+                       cp /var/ipfire/time/counter.conf /var/lock/time/counter
                else
                        case $tlanguage in
                                de ) logger -t ipfire "ntpdate fehlerhaft" ;;
index 9f75358261a893a08691b94ca871857f7e2f0376..9f581985a0037d26039bba67d3133438e1114391 100644 (file)
 # /usr/local/bin/timecheck
 
 if [ -e /var/ipfire/time/enable ]; then
-       if [ $(cat /var/ipfire/time/settings | grep period) ] && [ -e /var/ipfire/time/counter ]; then
-               if [ $(cat /var/ipfire/time/counter) -gt 0 ]; then
-                       echo $(($(cat /var/ipfire/time/counter)-5)) > /var/ipfire/time/counter
+       if [ $(cat /var/ipfire/time/settings | grep period) ] && [ -e /var/lock/time/counter ]; then
+               if [ $(cat /var/lock/time/counter) -gt 0 ]; then
+                       echo $(($(cat /var/lock/time/counter)-5)) > /var/lock/time/counter
                else
-                       touch /var/ipfire/time/settimenow
-                       rm -f /var/ipfire/time/counter
+                       touch /var/lock/time/settimenow
+                       rm -f /var/lock/time/counter
                fi
        else
                # EAO added 2003-08-14 for v1.3.1
                # if settings are restored from a backup
# /var/ipfire/time/counter will not exist
                if [ $(cat /var/ipfire/time/settings | grep periodic) ]; then
-                       touch /var/ipfire/time/settimenow
+                       touch /var/lock/time/settimenow
                fi
        fi
 
-       if [ -e /var/ipfire/time/settimenow ]; then
+       if [ -e /var/lock/time/settimenow ]; then
                if      [ -e /var/ipfire/time/settime.conf ]; then
                        /usr/local/bin/settime $(cat /var/ipfire/time/settime.conf)
                fi
@@ -44,18 +44,18 @@ if [ -n "$1" ]; then
                # EAO added 2003-08-14 for v1.3.1
                # if settings are restored from a backup
-               # /var/ipfire/time/counter will not exist
+               # /var/lock/time/counter will not exist
                if [ $(cat /var/ipfire/time/settings | grep periodic) ]; then